/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Edit Config Files.
 *
 * The Initial Developer of the Original Code is Satoshi Sakagami.
 * Portions created by the Initial Developer are Copyright (C) 2005-2006
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s): Satoshi Sakagami <saasan_s2works@yahoo.co.jp>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

var editconfigfilesOverlay = {
	onLoad : function() {
		editconfigfilesCommon.localizeDescription("editconfigfiles_description");

		this.applySettings();
	},

	applySettings : function() {
		var hidden = editconfigfilesCommon.getBoolPref("config.general.menuHidden", editconfigfilesCommon.defaultMenuHidden);
		document.getElementById("editconfigfiles-menu").hidden = hidden;
	},

	onMenu : function(file) {
		var editorPath = editconfigfilesCommon.getCharPref("config.editor.path", editconfigfilesCommon.defaultEditorPath);

		if (editorPath.length > 0) {
			this.openFile(editorPath, file);
		}
		else {
			editconfigfilesCommon.openSettingsDialog();
			return;
		}
	},

	openFile : function(editorPath, file) {
		var iEditor = editconfigfilesCommon.getLocalFileInterface(editorPath);

		if (!iEditor || !iEditor.exists()) {
			alert(editconfigfilesCommon.getString("msg_editor_not_found"));
			return;
		}

		var isDirectoryProfile = {
			"prefs.js" : true,
			"user.js" : true
		};

		var fileDirectory = "";

		if (isDirectoryProfile[file]) {
			fileDirectory = editconfigfilesCommon.getProfileDirectory();
		}
		else {
			fileDirectory = editconfigfilesCommon.getChromeDirectory();
		}

		var iFilePath = editconfigfilesCommon.getLocalFileInterface(fileDirectory);
		iFilePath.append(file);

		if (!iFilePath || !iFilePath.exists()) {
			var isExampleExists = {
				"userChrome.css" : true,
				"userContent.css" : true
			};

			if (isExampleExists[file]) {
				var exampleFile = editconfigfilesCommon.getLocalFileInterface(iFilePath.path.slice(0, -4) + "-example.css");

				if (!exampleFile || !exampleFile.exists()) {
					iFilePath.create(iFilePath.NORMAL_FILE_TYPE, 0664);
				}
				else {
					var iFileDirectory = editconfigfilesCommon.getLocalFileInterface(fileDirectory);
					exampleFile.copyTo(iFileDirectory, file);
				}
			}
			else {
				iFilePath.create(iFilePath.NORMAL_FILE_TYPE, 0664);
			}
		}

		if (!iFilePath || !iFilePath.exists()) {
			alert(editconfigfilesCommon.getFormattedString("msg_file_not_found", [file]));
			return;
		}

		editconfigfilesCommon.openFile(iEditor, iFilePath);
	},

	openProfileFolder : function() {
		editconfigfilesCommon.openDirectory(editconfigfilesCommon.getProfileDirectory());
	},

	openInstallationFolder : function() {
		editconfigfilesCommon.openDirectory(editconfigfilesCommon.getSpecialDirectory("CurProcD"));
	},

	openAboutConfig : function(event) {
		if (event.ctrlKey) {
			loadURI("about:config");
		}
		else {
			gBrowser.selectedTab = gBrowser.addTab("about:config");
		}
	},

	openAboutConfigTb : function() {
		const name = "Preferences:ConfigManager";
		const uri = "chrome://global/content/config.xul";

		var mediator = Components.classes["@mozilla.org/appshell/window-mediator;1"].getService(Components.interfaces.nsIWindowMediator);
		var w = mediator.getMostRecentWindow(name);

		if (w) {
			w.focus();
		}
		else {
			var watcher = Components.classes["@mozilla.org/embedcomp/window-watcher;1"].getService(Components.interfaces.nsIWindowWatcher);
			watcher.openWindow(null, uri, name, "chrome,resizable", null);
		}
	}
};

window.addEventListener("load", function() { editconfigfilesOverlay.onLoad(); }, false);
