/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is s2CommonClass.
 *
 * The Initial Developer of the Original Code is Satoshi Sakagami.
 * Portions created by the Initial Developer are Copyright (C) 2005-2006
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s): Satoshi Sakagami <saasan_s2works@yahoo.co.jp>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

function s2CommonClass() {
}

s2CommonClass.prototype = {
	getString : function(name) {
		var string = "";
		var stringBundle = document.getElementById(this.stringbundle_id);

		try {
			string = stringBundle.getString(name);
		}
		catch (e) {
			alert("getString:\n" + e);
		}
		finally {
			return string;
		}
	},

	getFormattedString : function(name, append) {
		var string = "";
		var stringBundle = document.getElementById(this.stringbundle_id);

		try {
			string = stringBundle.getFormattedString(name, append);
		}
		catch (e) {
			alert("getFormattedString:\n" + e);
		}
		finally {
			return string;
		}
	},

	getCharPref : function(prefName, defaultValue) {
		return nsPreferences.copyUnicharPref(this.pref_root + prefName, defaultValue);
	},

	setCharPref : function(prefName, value) {
		nsPreferences.setUnicharPref(this.pref_root + prefName, value);
	},

	getIntPref : function(prefName, defaultValue) {
		return nsPreferences.getIntPref(this.pref_root + prefName, defaultValue);
	},

	setIntPref : function(prefName, value) {
		nsPreferences.setIntPref(this.pref_root + prefName, value);
	},

	getBoolPref : function(prefName, defaultValue) {
		return nsPreferences.getBoolPref(this.pref_root + prefName, defaultValue);
	},

	setBoolPref : function(prefName, value) {
		nsPreferences.setBoolPref(this.pref_root + prefName, value);
	},

	getPrefFromId : function(id, defaultValue) {
		var element = document.getElementById(id);
		if (element) {
			switch (element.tagName) {
				case "textbox" : {
					element.value = this.getCharPref(id, defaultValue);
					break;
				}

				case "checkbox" : {
					element.checked = this.getBoolPref(id, defaultValue);
					break;
				}

				case "menulist" : {
					element.selectedIndex = this.getIntPref(id, defaultValue);
					break;
				}

				default : {
					break;
				}
			}
		}
	},

	setPrefFromId : function(id) {
		var element = document.getElementById(id);
		if (element) {
			switch (element.tagName) {
				case "textbox" : {
					this.setCharPref(id, element.value);
					break;
				}

				case "checkbox" : {
					this.setBoolPref(id, element.checked);
					break;
				}

				case "menulist" : {
					this.setIntPref(id, element.selectedIndex);
					break;
				}

				default : {
					break;
				}
			}
		}
	},

	openSettingsDialog : function() {
			window.openDialog(this.chrome_settings, "_blank", "chrome,dependent=yes");
	},

	createFilePicker : function(parent, title, mode, filter) {
		var filePicker = Components.classes["@mozilla.org/filepicker;1"].createInstance(Components.interfaces.nsIFilePicker);
		filePicker.init(parent, title, mode);
		filePicker.appendFilters(filter);

		return filePicker;
	},

	getSpecialDirectory : function(directoryString) {
		var service = Components.classes["@mozilla.org/file/directory_service;1"].getService(Components.interfaces.nsIProperties);
		return service.get(directoryString, Components.interfaces.nsIFile).path;
	},

	getProfileDirectory : function() {
		return this.getSpecialDirectory("ProfD");
	},

	getChromeDirectory : function() {
		return this.getSpecialDirectory("UChrm");
	},

	getLocalFileInterface : function(filePath) {
		try {
			var localFileInterface = Components.classes["@mozilla.org/file/local;1"].createInstance(Components.interfaces.nsILocalFile);
			localFileInterface.initWithPath(filePath);
			return localFileInterface;
		}
		catch (e) {
			return null;
		}
	},

	openFile : function(app, file) {
		var iMIMEService = Components.classes["@mozilla.org/uriloader/external-helper-app-service;1"].getService(Components.interfaces.nsIMIMEService);
		var iMIMEInfo = iMIMEService.getFromTypeAndExtension(file, null);

		iMIMEInfo.alwaysAskBeforeHandling = false;
		iMIMEInfo.preferredAction = Components.interfaces.nsIMIMEInfo.useHelperApp;
		iMIMEInfo.preferredApplicationHandler = app;

		iMIMEInfo.launchWithFile(file);
	},

	openDirectory : function(directory) {
		var iDirectory = this.getLocalFileInterface(directory);
		iDirectory.launch();
	},

	isFirefox : function() {
		return window.navigator.userAgent.indexOf("Firefox") >= 0;
	},

	localizeDescription : function(name) {
		var description = this.getString(name);

		if (description.length > 0) {
			nsPreferences.setUnicharPref("extensions." + this.guid + ".description", description);
		}
	}
}
